nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ctlstat

Struct Ctlstat 

#[repr(transparent)]
pub struct Ctlstat(pub u32);
Control and status register for DMA channel .

Tuple Fields

0: u32

Implementations

Source

impl Ctlstat

pub const fn validpending(&self) -> Validpending

Valid pending flag for this channel. This bit is set when a 1 is written to the corresponding bit in the related SETVALID register when CFGVALID = 1 for the same channel.

pub const fn set_validpending(&mut self, val: Validpending)

Valid pending flag for this channel. This bit is set when a 1 is written to the corresponding bit in the related SETVALID register when CFGVALID = 1 for the same channel.

pub const fn trig(&self) -> bool

Trigger flag. Indicates that the trigger for this channel is currently set. This bit is cleared at the end of an entire transfer or upon reload when CLRTRIG = 1.

pub const fn set_trig(&mut self, val: bool)

Trigger flag. Indicates that the trigger for this channel is currently set. This bit is cleared at the end of an entire transfer or upon reload when CLRTRIG = 1.