nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Intenclr0

Struct Intenclr0 

#[repr(transparent)]
pub struct Intenclr0(pub u32);
Interrupt Enable Clear for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Intenclr0

pub const fn clr(&self) -> u32

Writing ones to this register clears corresponding bits in the INTENSET0. Bit n corresponds to DMA channel n. The number of bits = number of DMA channels in this device. Other bits are reserved.

pub const fn set_clr(&mut self, val: u32)

Writing ones to this register clears corresponding bits in the INTENSET0. Bit n corresponds to DMA channel n. The number of bits = number of DMA channels in this device. Other bits are reserved.